@@ -56,6 +56,12 @@ public abstract class Json extends #1.SuperPage implements Downloadable {
 	 * @return レスポンスするインスタンス。null可。
 	 */
 	protected abstract Serializable outputMain( RequestParameter req ) throws PageException;
+	/**
+	 * 初回outputの呼び出しメイン処理。
+	 * @param req リクエスト内容。
+	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
+	 */
+	public void firstOutputMain( RequestParameter req ) throws PageException{}
 	/**
 	 * 出力情報の設定を行う。
 	 * @param from 遷移元ページ。直接呼ばれている場合はnullです。
