@@ -37,6 +37,15 @@ public class #4 extends #1.view#2.#4 implements Downloadable {
 		return null;
 	}
 
+	/**
+	 * 初回outputの呼び出しメイン処理。
+	 * @param req リクエスト内容。
+	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
+	 */
+	public void firstOutputMain( RequestParameter req ) throws PageException {
+		// 初期化処理があれば記述して下さい。
+	}
+
 	/**
 	 * 出力情報の設定を行う。
 	 * @param from 遷移元ページ。直接呼ばれている場合はnullです。
