@@ -115,7 +115,7 @@ public abstract class Page implements Serializable {
 		 * クライアント数が多く見込まれるサイトでは注意して下さい。
 		 */
 		SERVER_PUSH;
-		private static final long serialVersionUID = 1L;
+		private static final long serialVersionUID = 2L;
 	}
 
 	/**
@@ -136,6 +136,7 @@ public abstract class Page implements Serializable {
 
 	private boolean xml_f = false;
 	private String	doctype_def = null;
+	private static final long serialVersionUID = 2L;
 
 	/**
 	 * 実行状態であるか？常に true を返します。
@@ -881,5 +882,22 @@ public abstract class Page implements Serializable {
 	 * @return true:検出する、false:検出しない。
 	 */
 	public abstract boolean isCheckRepeatSameRequest();
+
+	/**
+	 * 初回outputの呼び出し直前にコールされます。初期化処理を記述します。
+	 * @param req リクエスト内容。
+	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
+	 */
+	public abstract void firstOutput( RequestParameter req ) throws PageException;
+
+	private boolean beginning_called = false;
+	/**
+	 * フレームワークが使用します。ここからfirstOutputが呼ばれます。
+	 */
+	public void beginning( RequestParameter req ) throws PageException {
+		if ( !beginning_called )	return;
+		beginning_called = true;
+		firstOutput( req );
+	}
 }
 
