@@ -20,7 +20,7 @@ import paraselene.css.*;
  * スレッドセーフです。
  */
 public class URIValue extends PlainText implements AttributeValuable, CSSValuable {
-	private static final long serialVersionUID = 1L;
+	private static final long serialVersionUID = 2L;
 	private static final String DOWNLOAD_DIR = "rabbit/";
 	/**
 	 * デフォルトのエンコード(UTF-8)。
@@ -38,7 +38,12 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 		return DEFAULT_ENC;
 	}
 
-	private static String strip( String org_url ) {
+	/**
+	 * CSSのURL表現、url(xxx)形式の記述から、xxx部分を取り出して返します。
+	 * @param org_url 取り出し対象文字列。
+	 * @return 取り出したURL。フォーマットが合わない場合、org_urlをそのまま返します。
+	 */
+	public static String CSSURLStrip( String org_url ) {
 		if ( org_url == null )	return null;
 		org_url = org_url.trim();
 		if ( org_url.length() < 6 )	return org_url;
@@ -66,7 +71,7 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 	public static boolean isCSSURL( String url ) {
 		if ( url == null )	return false;
 		url = url.trim();
-		return !url.equals( strip( url ) );
+		return !url.equals( CSSURLStrip( url ) );
 	}
 
 	/**
@@ -90,7 +95,7 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 	 * @return エンコード後の文字列。
 	 */
 	public static String encode( String uri, String enc ) throws UnsupportedEncodingException {
-		uri = strip( uri );
+		uri = CSSURLStrip( uri );
 		if ( enc == null )	enc = DEFAULT_ENC;
 		String[]	frag = uri.split( "#" );
 		if ( frag.length == 0 )	return uri;
@@ -160,17 +165,19 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 	 * @param enc setEncode()参照。
 	 */
 	public URIValue( String u, String enc ) throws UnsupportedEncodingException, URISyntaxException {
-		u = strip( u );
+		u = CSSURLStrip( u );
 		setEncode( enc );
 		setURI( makeURI( u, enc ), enc );
 	}
 
 	/**
-	 * コンストラクタ。エスケープされていないURIを格納します。
+	 * コンストラクタ。エスケープされていないURIを格納します。<br>
+	 * CSSのURL形式文字列を渡す事も可能ですが、そのパスがエスケープされていると
+	 * 正しく動作しません。
 	 * @param u URI。
 	 */
 	public URIValue( String u ) throws UnsupportedEncodingException, URISyntaxException {
-		this( strip( u ), null );
+		this( CSSURLStrip( u ), null );
 	}
 
 	/**
@@ -203,7 +210,7 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 	}
 
 	private static URI makeURI( String uri, String enc ) {
-		uri = strip( uri );
+		uri = CSSURLStrip( uri );
 		if ( uri == null )	return null;
 		try {
 			return new URI( encode( uri, enc ) );
@@ -443,7 +450,7 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 		}
 		catch( NoClassDefFoundError nc ) {
 			try {
-				ret = URIValue.encode( super.toString(), getCharset() );
+				ret = URIValue.encode( super.toString( StringMode.PLAIN ), getCharset() );
 			}
 			catch( Exception e2 ) {
 				Option.debug( e2 );
