@@ -9,7 +9,6 @@ package paraselene.dyna;
 import java.util.*;
 import paraselene.*;
 import paraselene.tag.*;
-import paraselene.tag.attr.*;
 
 
 class SaxContainer {
@@ -40,6 +39,8 @@ class SaxContainer {
 				Attribute	attr = nt.getAttribute( "http-equiv" );
 				if ( attr != null ) {
 					if ( "Content-Type".equalsIgnoreCase( attr.getString() ) ) {
+						attr = nt.getAttribute( "content" );
+						if ( attr != null )	pp.parse_encode = attr.getString();
 						nt.setVisible( false );
 					}
 				}
@@ -97,7 +98,7 @@ class SaxContainer {
 
 	void addText( char[] data, int start, int length, boolean xml_f ) {
 		String	name = tag.getName();
-		StringBuffer	buf = new StringBuffer();
+		StringBuilder	buf = new StringBuilder();
 		boolean			crlf_f = false;
 		length += start;
 		for ( int i = start; i < length; i++ ) {
@@ -122,7 +123,7 @@ class SaxContainer {
 			last_part = null;
 		}
 		if ( "noframes".equals( name ) ) {
-			StringBuffer	sub = new StringBuffer( "<body name='body'>" );
+			StringBuilder	sub = new StringBuilder( "<body name='body'>" );
 			sub = sub.append( buf );
 			sub = sub.append( "</body>" );
 			DynamicPage	sub_page = pp.makePage();
@@ -148,9 +149,6 @@ class SaxContainer {
 		}
 	}
 
-	void addComment( char[] data ) {
-		add( pp.makeComment( new String( data ) ) );
-	}
 }
 
 
