@@ -82,10 +82,6 @@ public enum Param {
 	HTML_ROOT( "-html",
 		"読み込むhtmlの配置ディレクトリ。その直下より再帰読み込みします。",
 		true, true ),
-	NEKO( "-neko",
-		"true を指定すると、HTMLのパースにCyberNeko HTML Parserを使用します。\n" +
-		"falseを指定すると、Java標準付属のパーサーを使用します。",
-		false, true, "false" ),
 	OUT_PATH( "-out",
 		"出力ディレクトリ。スケルトンソースファイルや定義ファイルの出力先です。\n" +
 		"出力ディレクトリが無ければ作成します。\n" +
@@ -130,23 +126,13 @@ public enum Param {
 		"ディレクトリ階層に関係なく、ディレクトリ名がマッチすると保護します。\n" +
 		"指定例) .svn   Subversionの管理ファイルを削除しない\n",
 		false, false ),
-	DTD( "-dtd",
-		"DTDキャッシュディレクトリ。\n" +
-		"ディレクトリを指定すると、その場所にダウンロードしたDTDを保存します。\n" +
-		"次回起動時に、指定ディレクトリに目的のDTDがあればリモートアクセスせずに\n" +
-		"それを使用します。\n" +
-		"ただし、HTMLファイルに対しては、このオプションは無視されます。",
-		false, true, System.getProperty( "java.io.tmpdir" ) ),
-	USER_AGENT( "-agent",
-		"DTDを取得する際のHTTPアクセスで使用するUser-Agent。", false, true,
-		"Mozilla/5.0 (compatible; " + System.getProperty( "os.name" ) + "; " +
-		System.getProperty( "user.language" ) + "-" +
-		System.getProperty( "user.country" ) + ") Paraselene " + Version.VERSION ),
 	IN_ENCODE( "-html_encode",
 		"HTMLファイルの文字コード。\n" +
-		"HTMLファイルは予め、この文字コードで統一しておいて下さい。\n" +
-		"ただし、XHTMLファイルに対しては、このオプションは無視されます。" ,
-		false, true, "UTF-8" ),
+		"これを指定する時は、全てのHTMLファイルは予め、この文字コードで\n" +
+		"統一しておいて下さい。\n" +
+		"これを指定しなかった場合、HTMLファイルの<META>タグより決定します。\n" +
+		"XHTMLファイルに対しては、このオプションは無視されます。" ,
+		false, true ),
 	OUT_ENCODE( "-output_encode",
 		"実行時の文字コード。\n" +
 		"実行時、ブラウザにはこの文字コードで出力されます。",
@@ -182,10 +168,6 @@ public enum Param {
 		"paraselene.dyna.GrantTagProvider を実装したクラス名を指定して下さい。\n" +
 		"このクラスにクラスパスが通されている必要があります。",
 		false, false ),
-	JSON( "-json",
-		"Paraselene が提供する Json クラス(非同期通信クラス)を使用する場合\n" +
-		"true を指定して下さい。使用しない場合は false を指定して下さい。",
-		false, true, "false" ),
 	INCLUDE( "-include",
 		"ソースファイル化するファイル。*?を使ったワイルドカード指定が可能です。",
 		false, false, HtmlExt.getParam() ),
@@ -321,7 +303,10 @@ public enum Param {
 			System.exit( 1 );
 		}
 		try {
-			URLEncoder.encode( "XXX", IN_ENCODE.get() );
+			String	str = IN_ENCODE.get();
+			if ( str != null ) {
+				URLEncoder.encode( "XXX", str );
+			}
 		}
 		catch(Exception e) {
 			System.err.println( IN_ENCODE.key + " の指定が不正です" );
@@ -341,20 +326,6 @@ public enum Param {
 			System.err.println( CLEAR.key + " の指定が不正です" );
 			System.exit( 1 );
 		}
-		try {
-			Boolean.valueOf( NEKO.get() );
-		}
-		catch(Exception e) {
-			System.err.println( NEKO.key + " の指定が不正です" );
-			System.exit( 1 );
-		}
-		try {
-			Boolean.valueOf( JSON.get() );
-		}
-		catch(Exception e) {
-			System.err.println( JSON.key + " の指定が不正です" );
-			System.exit( 1 );
-		}
 		try {
 			String	f = SOURCE_HEAD.get();
 			if ( f != null ) {
@@ -407,7 +378,7 @@ public enum Param {
 
 	private String getInfo() {
 		String[]	str = info.split( "\n" );
-		StringBuffer	buf = new StringBuffer();
+		StringBuilder	buf = new StringBuilder();
 		for ( int i = 0; i < str.length; i++ ) {
 			buf = buf.append( "    " );
 			buf = buf.append( str[i] );
