@@ -13,7 +13,7 @@ public class SourceHead {
 	private static String head = "";
 
 	public static void init( File f ) throws FileNotFoundException, IOException {
-		StringBuffer	buf = new StringBuffer();
+		StringBuilder	buf = new StringBuilder();
 		BufferedReader	br = new BufferedReader(
 			new InputStreamReader( new FileInputStream( f ) )
 		);
