@@ -679,10 +679,7 @@ public abstract class Supervisor extends HttpServlet {
 			return onErrorDebug( e, request, res );
 		}
 		req.setParam( method, request, this );
-		String[]	ua = req.getHeader( RequestParameter.UA_HEAD );
-		if ( ua != null ) {
-			holder.search_engine = SearchEngineAgent.isSearchEngineAgent( ua[0] );
-		}
+		holder.search_engine = req.judgSearchEngine() != RequestParameter.SearchEngine.NO_SEARCHENGINE;
 		holder.request = req;
 
 		int	cnt = getRequestMaxCount();
