@@ -18,7 +18,7 @@ import paraselene.mockup.*;
  * スレッドセーフです。
  */
 public class Attribute implements Serializable {
-	private static final long serialVersionUID = 1L;
+	private static final long serialVersionUID = 2L;
 	private String	name;
 	private AttributeValuable	value;
 	private Page	embed;
@@ -87,7 +87,17 @@ public class Attribute implements Serializable {
 	 * @param v 属性値。
 	 */
 	public void set( String v ) {
-		value = Converter.toAttributeValuable( getName(), v );
+		value = Converter.toAttributeValuable( getName(), v, null );
+		setPage( embed );
+	}
+
+	/**
+	 * 属性値の設定。
+	 * @param v 属性値。
+	 * @param dec URIデコード文字コード。
+	 */
+	public void set( String v, String dec ) {
+		value = Converter.toAttributeValuable( getName(), v, dec );
 		setPage( embed );
 	}
 
@@ -96,7 +106,17 @@ public class Attribute implements Serializable {
 	 * @param v 属性値。
 	 */
 	public void set( Valuable v ) {
-		value = Converter.toAttributeValuable( getName(), v );
+		value = Converter.toAttributeValuable( getName(), v, null );
+		setPage( embed );
+	}
+
+	/**
+	 * 属性値の設定。
+	 * @param v 属性値。
+	 * @param dec URIデコード文字コード。
+	 */
+	public void set( Valuable v, String dec ) {
+		value = Converter.toAttributeValuable( getName(), v, dec );
 		setPage( embed );
 	}
 
